pub struct System {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl System
impl System
Sourcepub async fn user_list(
&self,
limit: u32,
page_token: &str,
sort_by: NameSortMode,
) -> Result<Vec<UserBuiltin>>
pub async fn user_list( &self, limit: u32, page_token: &str, sort_by: NameSortMode, ) -> Result<Vec<UserBuiltin>>
List built-in users.
This function performs a GET to the /system/user endpoint.
Parameters:
limit: u32– Maximum number of items returned by a single call.page_token: &str– Token returned by previous call to retrieve the subsequent page.sort_by: crate::types::NameSortMode– Supported set of sort modes for scanning by name only
Currently, we only support scanning in ascending order.
Sourcepub async fn user_list_all(
&self,
sort_by: NameSortMode,
) -> Result<Vec<UserBuiltin>>
pub async fn user_list_all( &self, sort_by: NameSortMode, ) -> Result<Vec<UserBuiltin>>
List built-in users.
This function performs a GET to the /system/user endpoint.
As opposed to user_list, this function returns all the pages of the request at once.
Sourcepub async fn user_view(&self, user_name: &str) -> Result<UserBuiltin>
pub async fn user_view(&self, user_name: &str) -> Result<UserBuiltin>
Fetch a built-in user.
This function performs a GET to the /system/user/{user_name} endpoint.
Parameters:
user_name: &str– Names must begin with a lower case ASCII letter, be composed exclusively of lowercase ASCII, uppercase ASCII, numbers, and ‘-’, and may not end with a ‘-’. Names cannot be a UUID though they may contain a UUID.